==> aloe-1.4.tar.gz: aloe-1.4/modules/gen_SOURCEr1/interfaces/itf_types.h <==
#ifndef _ITF_TYPES
#define	_ITF_TYPES

//CONTROL GENERIC
////////////////////////////////////////////////////////////////////////////////
///////////////////////DATA CONTROL/////////////////////////////////////////////
/*Define the module control parameters*/

/*Values for "status"*/
#define NONACTIVE 	0
#define ACTIVE		1	/*Defines a module as active*/
#define TEST_FLOW	2	/*Test flows: Bypass data flow mode*/
#define TEST_PROCESS	3	/*Test Module Process*/

/*Values for signalflow*/
#define DATAFLOW                10  //bits
#define SAMPLES                 20  //Digital signal processing samples

/*Values for signaltype*/
/** Signal types*/
#define FROMTEXTFILE            11   //Data flow from text file
#define FROMPATTERN             12   //Always the same byte pattern
#define NUMBEREDSEQ             13
#define PATTERN                 0x3F

#define SEN                     21
#define COS                     22
#define RECT                    23
#define CUSTOM                  24

/*Control STRUCT                            */
typedef struct {		/*Defined according the control out needs*/
    int status;
    int time_slot;
    int inputdatalength;
    int outputdatalength;
    int transporttypeIN;
    int transporttypeOUT;
    int signalflow;
    int signaltype;
    /**  <-----------------         Additional module control variables here*/
}ControlMODULENAME_h;           /** MODULENAME to be modified according name of
                                 *  the module
                                 *  It is needed when a module controlling the
                                 *  other ones is used
                                 */


#endif

==> aloe-1.4.5.tar.gz: aloe-1.4.5/modules/gen_SOURCEr1/interfaces/itf_types.h <==
#ifndef _ITF_TYPES
#define	_ITF_TYPES

//CONTROL GENERIC
////////////////////////////////////////////////////////////////////////////////
///////////////////////DATA CONTROL/////////////////////////////////////////////
/*Define the module control parameters*/

/*Values for "status"*/
#define NONACTIVE 	0
#define ACTIVE		1	/*Defines a module as active*/
#define TEST_FLOW	2	/*Test flows: Bypass data flow mode*/
#define TEST_PROCESS	3	/*Test Module Process*/

/*Values for signalflow*/
#define DATAFLOW                10  //bits
#define SAMPLES                 20  //Digital signal processing samples

/*Values for signaltype*/
/** Signal types*/
#define FROMTEXTFILE            11   //Data flow from text file
#define FROMPATTERN             12   //Always the same byte pattern
#define NUMBEREDSEQ             13
#define PATTERN                 0x3F

#define SEN                     21
#define COS                     22
#define RECT                    23
#define CUSTOM                  24

/*Control STRUCT                            */
typedef struct {		/*Defined according the control out needs*/
    int status;
    int time_slot;
    int inputdatalength;
    int outputdatalength;
    int transporttypeIN;
    int transporttypeOUT;
    int signalflow;
    int signaltype;
    /**  <-----------------         Additional module control variables here*/
}ControlGEN_SOURCEr1_h;           /** MODULENAME to be modified according name of
                                 *  the module
                                 *  It is needed when a module controlling the
                                 *  other ones is used
                                 */


#endif
